summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorEdward Hervey <edward@collabora.com>2012-09-03 13:05:34 +0200
committerEdward Hervey <edward@collabora.com>2012-09-03 13:05:34 +0200
commit0d99a9290a8cdbfc61d9a957a08e6e79d248ca5f (patch)
tree638c4ae10d1f66653bff890768257923d9c98389
parent2863db9786b3f02da9855f021455c4c19738fba3 (diff)
gnlcomposition: Update for API change
-rw-r--r--gnl/gnlcomposition.c5
1 files changed, 2 insertions, 3 deletions
diff --git a/gnl/gnlcomposition.c b/gnl/gnlcomposition.c
index 42beb50..cbb6cff 100644
--- a/gnl/gnlcomposition.c
+++ b/gnl/gnlcomposition.c
@@ -476,7 +476,7 @@ wait_no_more_pads (GnlComposition * comp, gpointer object,
}
/* signal_duration_change
* Creates a new GST_MESSAGE_DURATION with the currently configured
* composition duration and sends that on the bus.
*/
@@ -484,8 +484,7 @@ static inline void
signal_duration_change (GnlComposition * comp)
{
gst_element_post_message (GST_ELEMENT_CAST (comp),
- gst_message_new_duration (GST_OBJECT_CAST (comp),
- GST_FORMAT_TIME, GNL_OBJECT_MEDIA_DURATION (comp)));
+ gst_message_new_duration_changed (GST_OBJECT_CAST (comp)));
}
static gboolean
@@ -476,7 +476,7 @@ wait_no_more_pads (GnlComposition * comp, gpointer object,
}
/* signal_duration_change
- * Creates a new GST_MESSAGE_DURATION with the currently configured
+ * Creates a new GST_MESSAGE_DURATION_CHANGED with the currently configured
* composition duration and sends that on the bus.
*/